@@ -1806,7 +1806,7 @@ void parse_maneuver(osrm_step_t &step, json::Object &maneuver)
         step.maneuver->location.latitude = location_array[1].get<json::Number>().value;
     }
     step.maneuver->type = get_string("type", maneuver);
-    step.maneuver->modifer = get_string("modifer", maneuver);
+    step.maneuver->modifier = get_string("modifier", maneuver);
 }
 
 void destroy_maneuver(osrm_maneuver_t *maneuver)
@@ -1820,9 +1820,9 @@ void destroy_maneuver(osrm_maneuver_t *maneuver)
     {
         free(maneuver->type);
     }
-    if(maneuver->modifer != NULL)
+    if(maneuver->modifier != NULL)
     {
-        free(maneuver->modifer);
+        free(maneuver->modifier);
     }
 
     free(maneuver);
